import numpy as np
import random as rnd
from sklearn.base import clone
from sklearn.model_selection import train_test_split
from tqdm import trange
from .gafs import SklearnGeneticSelection, bcolors
__version__ = '0.0.1'